@@ -10,7 +10,7 @@ use crate::parse_filter;
 use crate::protocol::LdapOp;
 use crate::result::{LdapError, LdapResult, Result};
 
-use tokio::sync::{mpsc, Mutex};
+use tokio::sync::{Mutex, mpsc};
 use tokio::time;
 
 use lber::common::TagClass;
@@ -29,9 +29,10 @@ pub enum Scope {
 }
 
 /// Possible values for alias dereferencing during search.
-#[derive(Clone, Copy, Debug, PartialEq)]
+#[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub enum DerefAliases {
     /// Never dereference.
+    #[default]
     Never = 0,
     /// Dereference while retrieving objects according to search scope.
     Searching = 1,
@@ -41,12 +42,6 @@ pub enum DerefAliases {
     Always = 3,
 }
 
-impl Default for DerefAliases {
-    fn default() -> Self {
-        DerefAliases::Never
-    }
-}
-
 #[derive(Debug)]
 pub enum SearchItem {
     Entry(StructureTag),
@@ -110,12 +105,17 @@ impl SearchOptions {
     ///
     /// This is a server-side limit of the elapsed time for performing the operation, _not_ a
     /// network timeout for retrieving result entries or the result of the whole operation.
+    ///
+    /// The limit applies to a single protocol operation; if multiple operations are involved,
+    /// as in a Search with the PagedResult control, the limit won't apply to all of them.
     pub fn timelimit(mut self, timelimit: i32) -> Self {
         self.timelimit = timelimit;
         self
     }
 
     /// Set the size limit, in entries, for the whole search operation.
+    ///
+    /// For applicability, see the last paragraph of the `timelimit()` method.
     pub fn sizelimit(mut self, sizelimit: i32) -> Self {
         self.sizelimit = sizelimit;
         self
@@ -133,7 +133,7 @@ impl SearchOptions {
 /// attribute can contain unconstrained binary strings, the conversion may fail. In that case,
 /// the attribute and all its values will be in the `bin_attrs` hashmap. Since it's
 /// possible that a particular set of values for a binary attribute _could_ be
-/// converted into UTF-8 `String`s, the presence of of such attribute in the result
+/// converted into UTF-8 `String`s, the presence of such an attribute in the result
 /// entry should be checked for both in `attrs` and `bin_atrrs`.
 #[derive(Debug, Clone)]
 pub struct SearchEntry {
@@ -691,7 +691,7 @@ where
         };
         match item {
             SearchItem::Entry(tag) | SearchItem::Referral(tag) => {
-                return Ok(Some(ResultEntry(tag, controls)))
+                return Ok(Some(ResultEntry(tag, controls)));
             }
             SearchItem::Done(mut res) => {
                 res.ctrls = controls;
@@ -743,7 +743,7 @@ where
         let adapter = self.adapters[self.ax].clone();
         let mut adapter = adapter.lock().await;
         self.ax += 1;
-        let res = (&mut adapter).start(self, base, scope, filter, attrs).await;
+        let res = adapter.start(self, base, scope, filter, attrs).await;
         self.ax -= 1;
         if res.is_err() {
             self.state = StreamState::Error;
@@ -770,7 +770,7 @@ where
         let adapter = self.adapters[self.ax].clone();
         let mut adapter = adapter.lock().await;
         self.ax += 1;
-        let res = (&mut adapter).next(self).await;
+        let res = adapter.next(self).await;
         self.ax -= 1;
         match res {
             Ok(None) if self.ax == 0 => self.state = StreamState::Done,
@@ -805,7 +805,7 @@ where
         let adapter = self.adapters[self.ax].clone();
         let mut adapter = adapter.lock().await;
         self.ax += 1;
-        let res = (&mut adapter).finish(self).await;
+        let res = adapter.finish(self).await;
         self.ax -= 1;
         res
     }
